@@ -7,7 +7,7 @@ from sklearn.preprocessing import FunctionTransformer, KBinsDiscretizer, OneHotE
 from sklearn.feature_extraction.text import TfidfVectorizer
 from sklearn.feature_selection import SelectPercentile, chi2, f_classif
 from sklearn.model_selection import RandomizedSearchCV
-from sklearn.svm import LinearSVC
+# from sklearn.svm import LinearSVC
 from sklearn.linear_model import PassiveAggressiveClassifier, Perceptron, RidgeClassifier, SGDClassifier
 from sklearn.naive_bayes import BernoulliNB, ComplementNB, MultinomialNB
 from sklearn.neighbors import KNeighborsClassifier, NearestCentroid
@@ -72,7 +72,8 @@ def factory_pipeline(x, y, tknz="spacy",
       fixed and cannot be user-defined.
     - Tokenization and lemmatization of the text feature: uses ``spaCy`` (default) or `NLTK <https://www.nltk.org/>`_.
       It also strips punctuation, excess spaces, and metacharacters "r" and "n" from the text. It converts emojis into
-      "__text__" (where "text" is the emoji name), and NA/NULL values into "__notext__".
+      "__text__" (where "text" is the emoji name), and NA/NULL values into "__notext__" (the pipeline does get rid of
+      records with no text, but this conversion at least deals with any escaping ones).
     - Feature selection: Uses `sklearn.feature_selection.SelectPercentile
       <https://scikit-learn.org/stable/modules/generated/sklearn.feature_selection.SelectPercentile.html>`_
       with `sklearn.feature_selection.chi2
@@ -84,8 +85,8 @@ def factory_pipeline(x, y, tknz="spacy",
       <https://scikit-learn.org/stable/modules/classes.html>`_.
 
     The numeric values in the grid are currently lists/tuples of values that are defined either empirically or
-    are based on the published literature (e.g. for Random Forest, see `Probst et al. 2019 <https://arxiv.org/abs/1802.09596>`_).
-    Values may be replaced by appropriate distributions in a future release.
+    are based on the published literature (e.g. for Random Forest, see `Probst et al. 2019
+    <https://arxiv.org/abs/1802.09596>`_). Values may be replaced by appropriate distributions in a future release.
 
      **NOTE:** As described later, argument `theme` is for internal use by Nottinghamshire Healthcare NHS Foundation
      Trust or other trusts who use the theme ("Access", "Environment/ facilities" etc.) labels. It can otherwise be
@@ -93,7 +94,7 @@ def factory_pipeline(x, y, tknz="spacy",
 
     :param bool ordinal: Whether to fit an ordinal classification model. The ordinal model is the implementation of
         `Frank and Hall (2001) <https://www.cs.waikato.ac.nz/~eibe/pubs/ordinal_tech_report.pdf>`_ that can use any
-        standard classification model.
+        standard classification model that calculates probabilities.
     :param x: The text feature.
     :param y: The response variable.
     :param str tknz: Tokenizer to use ("spacy" or "wordnet").
@@ -286,17 +287,17 @@ def factory_pipeline(x, y, tknz="spacy",
                     [OneHotEncoder(categories=onehot_categories), ThemeBinarizer(class_col='theme',
                                                                                  target_class="Couldn't be improved")]
 
-            if i.__class__.__name__ == LinearSVC().__class__.__name__:
-                aux['clf__estimator__max_iter'] = [10000]
-                aux['clf__estimator__class_weight'] = [None, 'balanced']
-                # aux['clf__estimator__dual'] = [True, False] # https://stackoverflow.com/questions/52670012/convergencewarning-liblinear-failed-to-converge-increase-the-number-of-iterati
+            # if i.__class__.__name__ == LinearSVC().__class__.__name__:
+            #     aux['clf__estimator__max_iter'] = [10000]
+            #     aux['clf__estimator__class_weight'] = [None, 'balanced']
+            #     # aux['clf__estimator__dual'] = [True, False] # https://stackoverflow.com/questions/52670012/convergencewarning-liblinear-failed-to-converge-increase-the-number-of-iterati
             if i.__class__.__name__ == BernoulliNB().__class__.__name__:
                 aux['clf__estimator__alpha'] = (0.1, 0.5, 1)
             if i.__class__.__name__ == ComplementNB().__class__.__name__:
                 aux['clf__estimator__alpha'] = (0.1, 0.5, 1)
             if i.__class__.__name__ == MultinomialNB().__class__.__name__:
                 aux['clf__estimator__alpha'] = (0.1, 0.5, 1)
-            if i.__class__.__name__ == SGDClassifier().__class__.__name__:  # Perhaps try out loss='log' at some point?
+            if i.__class__.__name__ == SGDClassifier().__class__.__name__:
                 aux['clf__estimator__max_iter'] = [10000]
                 aux['clf__estimator__class_weight'] = [None, 'balanced']
                 aux['clf__estimator__penalty'] = ('l2', 'elasticnet')
